/*
 *  
 *  $Id: imprimevistasimple.h 3830 2011-05-06 13:30:18Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include <api/controllers/ipacscontroller.h>
#include <export/icontratoscore.h>
#include <api/iimpresion.h>

class vtkImageReslice;
class vtkScalarsToColors;

namespace GNKVisualizator {
	class ImprimeVistaSimple  : public GNC::GCS::IImpresion {
	public:
		ImprimeVistaSimple(GNC::GCS::IWidgetsManager* pWidgetsManager, GnkPtr<GNC::GCS::IContextoEstudio> estudioAprimaria, int index );
		~ImprimeVistaSimple();

	//region "exportacion de imagenes"
		void PrintImageRGB(GNC::GCS::IContratoExportacionImages::ImageType::Pointer& img, bool conWidgets, const GNC::GCS::Vector& size);
		void PrintImage(GNC::GCS::IContratoExportacionImages::ImageType::Pointer& img, bool conWidgets, vtkScalarsToColors* pLookUpTable, const GNC::GCS::Vector& size);
	//endregion
		
	protected:
	};
}
